Class: Unparser::Buffer
- Inherits:
-
Object
- Object
- Unparser::Buffer
- Defined in:
- lib/unparser/buffer.rb
Overview
Buffer used to emit into
Constant Summary collapse
- NL =
"\n".freeze
Instance Method Summary collapse
-
#append(string) ⇒ self
private
Append string.
-
#append_without_prefix(string) ⇒ self
private
Append a string without an indentation prefix.
-
#capture_content ⇒ String
private
Capture the content written to the buffer within the block.
-
#content ⇒ String
private
Return content of buffer.
-
#fresh_line? ⇒ Boolean
private
Test for a fresh line.
-
#indent ⇒ self
private
Increase indent.
-
#initialize ⇒ undefined
constructor
private
Initialize object.
-
#nl ⇒ self
private
Write newline.
-
#unindent ⇒ self
private
Decrease indent.
Constructor Details
#initialize ⇒ undefined
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Initialize object
16 17 18 19 |
# File 'lib/unparser/buffer.rb', line 16 def initialize @content = '' @indent = 0 end |
Instance Method Details
#append(string) ⇒ self
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Append string
29 30 31 32 33 34 35 |
# File 'lib/unparser/buffer.rb', line 29 def append(string) if @content[-1].eql?(NL) prefix end write(string) self end |
#append_without_prefix(string) ⇒ self
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Append a string without an indentation prefix
45 46 47 48 |
# File 'lib/unparser/buffer.rb', line 45 def append_without_prefix(string) write(string) self end |
#capture_content ⇒ String
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Capture the content written to the buffer within the block
109 110 111 112 113 |
# File 'lib/unparser/buffer.rb', line 109 def capture_content size_before = @content.size yield @content[size_before..-1] end |
#content ⇒ String
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Return content of buffer
99 100 101 |
# File 'lib/unparser/buffer.rb', line 99 def content @content.dup.freeze end |
#fresh_line? ⇒ Boolean
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Test for a fresh line
89 90 91 |
# File 'lib/unparser/buffer.rb', line 89 def fresh_line? @content.empty? || @content[-1].eql?(NL) end |
#indent ⇒ self
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Increase indent
56 57 58 59 |
# File 'lib/unparser/buffer.rb', line 56 def indent @indent += 1 self end |
#nl ⇒ self
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Write newline
78 79 80 81 |
# File 'lib/unparser/buffer.rb', line 78 def nl write(NL) self end |
#unindent ⇒ self
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Decrease indent
67 68 69 70 |
# File 'lib/unparser/buffer.rb', line 67 def unindent @indent -= 1 self end |